function [residual, g1, g2, g3] = modelans123_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(7, 1);
T43 = (1+params(8)-params(4)/(params(4)-1))*(1-params(4))+params(4)*(y(6)*params(2)*y(4)/y(7)-1);
T50 = 1+params(5)*(y(5)-1)^2/2;
T63 = 1+(y(5)-1)^2*params(5)/2;
lhs =y(3);
rhs =params(9)/params(3)-1+params(7)*(y(10)-params(9));
residual(1)= lhs-rhs;
lhs =1/(1+y(3));
rhs =params(3)*y(6)/(y(10)*y(11));
residual(2)= lhs-rhs;
residual(3) = T43*T50-y(5)*params(5)*(y(5)-1)+y(10)*params(3)*params(5)*(y(10)-1);
residual(4) = y(6)*T63-y(4)*y(7);
lhs =log(y(7));
rhs =x(it_, 1)+1.85*log(y(1))-0.855*log(y(2));
residual(5)= lhs-rhs;
lhs =1/(1+y(8));
rhs =params(3)*y(7)/y(12);
residual(6)= lhs-rhs;
lhs =y(9);
rhs =y(1);
residual(7)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(7, 13);

  %
  % Jacobian matrix
  %

  g1(1,3)=1;
  g1(1,10)=(-params(7));
  g1(2,3)=(-1)/((1+y(3))*(1+y(3)));
  g1(2,10)=(-((-(params(3)*y(6)*y(11)))/(y(10)*y(11)*y(10)*y(11))));
  g1(2,6)=(-(params(3)/(y(10)*y(11))));
  g1(2,11)=(-((-(y(10)*params(3)*y(6)))/(y(10)*y(11)*y(10)*y(11))));
  g1(3,4)=T50*params(4)*y(6)*params(2)/y(7);
  g1(3,5)=T43*params(5)*2*(y(5)-1)/2-(params(5)*(y(5)-1)+params(5)*y(5));
  g1(3,10)=params(3)*params(5)*(y(10)-1)+y(10)*params(3)*params(5);
  g1(3,6)=T50*params(4)*params(2)*y(4)/y(7);
  g1(3,7)=T50*params(4)*(-(y(6)*params(2)*y(4)))/(y(7)*y(7));
  g1(4,4)=(-y(7));
  g1(4,5)=y(6)*params(5)/2*2*(y(5)-1);
  g1(4,6)=T63;
  g1(4,7)=(-y(4));
  g1(5,1)=(-(1.85*1/y(1)));
  g1(5,7)=1/y(7);
  g1(5,13)=(-1);
  g1(5,2)=0.855*1/y(2);
  g1(6,7)=(-(params(3)/y(12)));
  g1(6,12)=(-((-(params(3)*y(7)))/(y(12)*y(12))));
  g1(6,8)=(-1)/((1+y(8))*(1+y(8)));
  g1(7,1)=(-1);
  g1(7,9)=1;
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],7,169);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],7,2197);
end
end
