function [residual, g1, g2] = modelans123_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 7, 1);

%
% Model equations
%

T42 = (1+params(8)-params(4)/(params(4)-1))*(1-params(4))+params(4)*(y(4)*params(2)*y(2)/y(5)-1);
T48 = 1+params(5)*(y(3)-1)^2/2;
T60 = 1+(y(3)-1)^2*params(5)/2;
lhs =y(1);
rhs =params(9)/params(3)-1+params(7)*(y(3)-params(9));
residual(1)= lhs-rhs;
lhs =1/(1+y(1));
rhs =params(3)*y(4)/(y(3)*y(4));
residual(2)= lhs-rhs;
residual(3) = T42*T48-y(3)*params(5)*(y(3)-1)+y(3)*(y(3)-1)*params(3)*params(5);
residual(4) = y(4)*T60-y(2)*y(5);
lhs =log(y(5));
rhs =x(1)+log(y(5))*1.85-0.855*log(y(7));
residual(5)= lhs-rhs;
lhs =1/(1+y(6));
rhs =params(3)*y(5)/y(5);
residual(6)= lhs-rhs;
lhs =y(7);
rhs =y(5);
residual(7)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(7, 7);

  %
  % Jacobian matrix
  %

  g1(1,1)=1;
  g1(1,3)=(-params(7));
  g1(2,1)=(-1)/((1+y(1))*(1+y(1)));
  g1(2,3)=(-((-(y(4)*params(3)*y(4)))/(y(3)*y(4)*y(3)*y(4))));
  g1(2,4)=(-((params(3)*y(3)*y(4)-y(3)*params(3)*y(4))/(y(3)*y(4)*y(3)*y(4))));
  g1(3,2)=T48*params(4)*y(4)*params(2)/y(5);
  g1(3,3)=T42*params(5)*2*(y(3)-1)/2-(params(5)*(y(3)-1)+y(3)*params(5))+(y(3)-1)*params(3)*params(5)+y(3)*params(3)*params(5);
  g1(3,4)=T48*params(4)*params(2)*y(2)/y(5);
  g1(3,5)=T48*params(4)*(-(y(4)*params(2)*y(2)))/(y(5)*y(5));
  g1(4,2)=(-y(5));
  g1(4,3)=y(4)*params(5)/2*2*(y(3)-1);
  g1(4,4)=T60;
  g1(4,5)=(-y(2));
  g1(5,5)=1/y(5)-1.85*1/y(5);
  g1(5,7)=0.855*1/y(7);
  g1(6,6)=(-1)/((1+y(6))*(1+y(6)));
  g1(7,5)=(-1);
  g1(7,7)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],7,49);
end
end
