function [residual, g1, g2, g3] = modelans4_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           columns: equations in order of declaration
%                                                           rows: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              columns: equations in order of declaration
%                                                              rows: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(11, 1);
T35 = (1+params(8)-params(4)/(params(4)-1))*(1-params(4))+params(4)*(y(8)*params(2)*y(6)/y(10)-1);
T42 = 1+params(5)*(y(7)-1)^2/2;
T55 = 1+(y(7)-1)^2*params(5)/2;
T77 = (-1)/((1+y(5))*(1+y(5)));
T92 = T42*params(4)*y(8)*params(2)/y(10);
T98 = params(5)/2*2*(y(7)-1);
T99 = y(8)*T98;
T102 = params(5)*2*(y(7)-1)/2;
T109 = params(10)^(-1);
T137 = T42*params(4)*params(2)*y(6)/y(10);
T156 = 1/y(10);
T163 = params(4)*(-(y(8)*params(2)*y(6)))/(y(10)*y(10));
T164 = T42*T163;
T184 = (1+y(5)+1+y(5))/((1+y(5))*(1+y(5))*(1+y(5))*(1+y(5)));
T189 = params(4)*y(8)*params(2)/y(10)*T102;
T190 = y(12)*T189;
T193 = T42*params(4)*params(2)/y(10);
T199 = T42*params(4)*(-(y(8)*params(2)))/(y(10)*y(10));
T207 = 2*params(5)/2;
T216 = y(8)*y(7)*y(8)*y(7)*y(8)*y(7)*y(8)*y(7);
T218 = (-((-((-(y(8)*params(3)*y(1)))*(y(8)*y(8)*y(7)+y(8)*y(8)*y(7))))/T216));
T228 = T102*params(4)*params(2)*y(6)/y(10);
T235 = (-((y(8)*y(7)*y(8)*y(7)*(-(params(3)*y(1)))-(-(y(7)*params(3)*y(1)))*(y(8)*y(8)*y(7)+y(8)*y(8)*y(7)))/T216));
T246 = (-((-(params(3)*y(17)))/(y(17)*y(16)*y(17)*y(16))));
T268 = y(8)*y(7)*y(8)*y(7)*(-(params(3)*y(1)))-(-(y(8)*params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7));
T277 = (-((-1)/(y(8)*y(8))));
T282 = (-((-((-(y(7)*params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))))/T216));
T289 = T42*params(4)*(-(params(2)*y(6)))/(y(10)*y(10));
T294 = (-((-(params(3)*y(16)))/(y(17)*y(16)*y(17)*y(16))));
T303 = (-1)/(y(10)*y(10));
T310 = params(4)*(-((-(y(8)*params(2)*y(6)))*(y(10)+y(10))))/(y(10)*y(10)*y(10)*y(10));
T332 = y(12)*params(4)*y(8)*params(2)/y(10)*T207;
T334 = y(12)*T102*params(4)*params(2)/y(10);
T336 = y(12)*T102*params(4)*(-(y(8)*params(2)))/(y(10)*y(10));
T341 = y(12)*T42*params(4)*(-params(2))/(y(10)*y(10));
T347 = y(12)*T42*params(4)*(-((-(y(8)*params(2)))*(y(10)+y(10))))/(y(10)*y(10)*y(10)*y(10));
T352 = y(8)*y(7)*y(8)*y(7)*(y(8)*y(8)*y(7)+y(8)*y(8)*y(7))+y(8)*y(7)*y(8)*y(7)*(y(8)*y(8)*y(7)+y(8)*y(8)*y(7));
T410 = y(12)*T102*params(4)*(-(params(2)*y(6)))/(y(10)*y(10));
T433 = y(17)*y(16)*y(17)*y(16)*y(17)*y(16)*y(17)*y(16);
T493 = y(12)*T42*params(4)*(-((-(params(2)*y(6)))*(y(10)+y(10))))/(y(10)*y(10)*y(10)*y(10));
residual(1) = y(11)*T77;
residual(2) = y(15)*params(2)*2*y(6)/2+y(13)*(-y(10))+y(12)*T92;
residual(3) = y(13)*T99+y(12)*(T35*T102-(params(5)*(y(7)-1)+params(5)*y(7)))+T109*y(3)*(-((-(y(8)*params(3)*y(1)))/(y(8)*y(7)*y(8)*y(7))))+T109*y(4)*((y(7)-1)*params(3)*params(5)+y(7)*params(3)*params(5));
residual(4) = y(15)*(-(1/y(8)))+T55*y(13)+y(12)*T137+y(11)*(-(params(3)/(y(17)*y(16))))+T109*y(3)*(-((-(y(7)*params(3)*y(1)))/(y(8)*y(7)*y(8)*y(7))));
residual(5) = 1+y(15);
residual(6) = y(14)*T156+y(13)*(-y(6))+y(12)*T164+params(10)*y(18)*(-(params(6)*T156));
residual(7) = 1/(1+y(5))-params(3)*y(8)/(y(17)*y(16));
residual(8) = T35*T42-y(7)*params(5)*(y(7)-1)+y(16)*params(3)*params(5)*(y(16)-1);
residual(9) = y(8)*T55-y(6)*y(10);
residual(10) = log(y(10))-(params(6)*log(y(2))+x(it_, 1));
residual(11) = y(9)-(log(y(8))-params(2)*y(6)^2/2);
if nargout >= 2,
  g1 = zeros(11, 19);

  %
  % Jacobian matrix
  %

  g1(1,5)=y(11)*T184;
  g1(1,11)=T77;
  g1(2,6)=y(15)*2*params(2)/2;
  g1(2,7)=T190;
  g1(2,8)=y(12)*T193;
  g1(2,10)=(-y(13))+y(12)*T199;
  g1(2,12)=T92;
  g1(2,13)=(-y(10));
  g1(2,15)=params(2)*2*y(6)/2;
  g1(3,6)=T190;
  g1(3,7)=y(13)*y(8)*2*params(5)/2+y(12)*(T35*T207-(params(5)+params(5)))+T109*y(3)*T218+T109*y(4)*(params(3)*params(5)+params(3)*params(5));
  g1(3,1)=T109*y(3)*(-((-(params(3)*y(8)))/(y(8)*y(7)*y(8)*y(7))));
  g1(3,8)=y(13)*T98+y(12)*T228+T109*y(3)*(-(T268/T216));
  g1(3,10)=y(12)*T102*T163;
  g1(3,3)=T109*(-((-(y(8)*params(3)*y(1)))/(y(8)*y(7)*y(8)*y(7))));
  g1(3,4)=T109*((y(7)-1)*params(3)*params(5)+y(7)*params(3)*params(5));
  g1(3,12)=T35*T102-(params(5)*(y(7)-1)+params(5)*y(7));
  g1(3,13)=T99;
  g1(4,6)=y(12)*T193;
  g1(4,7)=y(13)*T98+y(12)*T228+T109*y(3)*T235;
  g1(4,16)=y(11)*T246;
  g1(4,1)=T109*y(3)*(-((-(params(3)*y(7)))/(y(8)*y(7)*y(8)*y(7))));
  g1(4,8)=y(15)*T277+T109*y(3)*T282;
  g1(4,17)=y(11)*T294;
  g1(4,10)=y(12)*T289;
  g1(4,3)=T109*(-((-(y(7)*params(3)*y(1)))/(y(8)*y(7)*y(8)*y(7))));
  g1(4,11)=(-(params(3)/(y(17)*y(16))));
  g1(4,12)=T137;
  g1(4,13)=T55;
  g1(4,15)=(-(1/y(8)));
  g1(5,15)=1;
  g1(6,6)=(-y(13))+y(12)*T199;
  g1(6,7)=y(12)*T102*T163;
  g1(6,8)=y(12)*T289;
  g1(6,10)=y(14)*T303+y(12)*T42*T310+params(10)*y(18)*(-(params(6)*T303));
  g1(6,12)=T164;
  g1(6,13)=(-y(6));
  g1(6,14)=T156;
  g1(6,18)=params(10)*(-(params(6)*T156));
  g1(7,5)=T77;
  g1(7,16)=(-((-(params(3)*y(8)*y(17)))/(y(17)*y(16)*y(17)*y(16))));
  g1(7,8)=(-(params(3)/(y(17)*y(16))));
  g1(7,17)=(-((-(params(3)*y(8)*y(16)))/(y(17)*y(16)*y(17)*y(16))));
  g1(8,6)=T92;
  g1(8,7)=T35*T102-(params(5)*(y(7)-1)+params(5)*y(7));
  g1(8,16)=params(3)*params(5)*(y(16)-1)+y(16)*params(3)*params(5);
  g1(8,8)=T137;
  g1(8,10)=T164;
  g1(9,6)=(-y(10));
  g1(9,7)=T99;
  g1(9,8)=T55;
  g1(9,10)=(-y(6));
  g1(10,2)=(-(params(6)*1/y(2)));
  g1(10,10)=T156;
  g1(10,19)=(-1);
  g1(11,6)=params(2)*2*y(6)/2;
  g1(11,8)=(-(1/y(8)));
  g1(11,9)=1;
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(160,3);
  v2(1,1)=1;
  v2(1,2)=81;
  v2(1,3)=y(11)*(2*(1+y(5))*(1+y(5))*(1+y(5))*(1+y(5))-(1+y(5)+1+y(5))*((1+y(5))*(1+y(5))*(1+y(5)+1+y(5))+(1+y(5))*(1+y(5))*(1+y(5)+1+y(5))))/((1+y(5))*(1+y(5))*(1+y(5))*(1+y(5))*(1+y(5))*(1+y(5))*(1+y(5))*(1+y(5)));
  v2(2,1)=1;
  v2(2,2)=195;
  v2(2,3)=T184;
  v2(3,1)=1;
  v2(3,2)=87;
  v2(3,3)=  v2(2,3);
  v2(4,1)=2;
  v2(4,2)=121;
  v2(4,3)=T332;
  v2(5,1)=2;
  v2(5,2)=140;
  v2(5,3)=T334;
  v2(6,1)=2;
  v2(6,2)=122;
  v2(6,3)=  v2(5,3);
  v2(7,1)=2;
  v2(7,2)=178;
  v2(7,3)=T336;
  v2(8,1)=2;
  v2(8,2)=124;
  v2(8,3)=  v2(7,3);
  v2(9,1)=2;
  v2(9,2)=179;
  v2(9,3)=T341;
  v2(10,1)=2;
  v2(10,2)=143;
  v2(10,3)=  v2(9,3);
  v2(11,1)=2;
  v2(11,2)=181;
  v2(11,3)=T347;
  v2(12,1)=2;
  v2(12,2)=216;
  v2(12,3)=T189;
  v2(13,1)=2;
  v2(13,2)=126;
  v2(13,3)=  v2(12,3);
  v2(14,1)=2;
  v2(14,2)=217;
  v2(14,3)=T193;
  v2(15,1)=2;
  v2(15,2)=145;
  v2(15,3)=  v2(14,3);
  v2(16,1)=2;
  v2(16,2)=219;
  v2(16,3)=T199;
  v2(17,1)=2;
  v2(17,2)=183;
  v2(17,3)=  v2(16,3);
  v2(18,1)=2;
  v2(18,2)=238;
  v2(18,3)=(-1);
  v2(19,1)=2;
  v2(19,2)=184;
  v2(19,3)=  v2(18,3);
  v2(20,1)=2;
  v2(20,2)=272;
  v2(20,3)=2*params(2)/2;
  v2(21,1)=2;
  v2(21,2)=110;
  v2(21,3)=  v2(20,3);
  v2(22,1)=3;
  v2(22,2)=120;
  v2(22,3)=T332;
  v2(23,1)=3;
  v2(23,2)=102;
  v2(23,3)=  v2(22,3);
  v2(24,1)=3;
  v2(24,2)=121;
  v2(24,3)=T109*y(3)*(-((T216*(-((-(y(8)*params(3)*y(1)))*(y(8)*y(8)+y(8)*y(8))))-(-((-(y(8)*params(3)*y(1)))*(y(8)*y(8)*y(7)+y(8)*y(8)*y(7))))*T352)/(T216*T216)));
  v2(25,1)=3;
  v2(25,2)=7;
  v2(25,3)=T109*y(3)*(-((-((y(8)*y(8)*y(7)+y(8)*y(8)*y(7))*(-(params(3)*y(8)))))/T216));
  v2(26,1)=3;
  v2(26,2)=115;
  v2(26,3)=  v2(25,3);
  v2(27,1)=3;
  v2(27,2)=139;
  v2(27,3)=T334;
  v2(28,1)=3;
  v2(28,2)=103;
  v2(28,3)=  v2(27,3);
  v2(29,1)=3;
  v2(29,2)=140;
  v2(29,3)=y(13)*2*params(5)/2+y(12)*params(4)*params(2)*y(6)/y(10)*T207+T109*y(3)*(-((T216*((y(8)*y(8)*y(7)+y(8)*y(8)*y(7))*(-(params(3)*y(1)))-(-(y(8)*params(3)*y(1)))*(y(8)*y(7)+y(8)*y(7)+y(8)*y(7)+y(8)*y(7)))-T268*T352)/(T216*T216)));
  v2(30,1)=3;
  v2(30,2)=122;
  v2(30,3)=  v2(29,3);
  v2(31,1)=3;
  v2(31,2)=134;
  v2(31,3)=T109*y(3)*(-((y(8)*y(7)*y(8)*y(7)*(-params(3))-(-(params(3)*y(8)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7)))/T216));
  v2(32,1)=3;
  v2(32,2)=8;
  v2(32,3)=  v2(31,3);
  v2(33,1)=3;
  v2(33,2)=141;
  v2(33,3)=T109*y(3)*(-((T216*((-(params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))-((-(params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))+(-(y(8)*params(3)*y(1)))*(y(7)*y(7)+y(7)*y(7))))-T268*(y(8)*y(7)*y(8)*y(7)*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))+y(8)*y(7)*y(8)*y(7)*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))))/(T216*T216)));
  v2(34,1)=3;
  v2(34,2)=177;
  v2(34,3)=T336;
  v2(35,1)=3;
  v2(35,2)=105;
  v2(35,3)=  v2(34,3);
  v2(36,1)=3;
  v2(36,2)=178;
  v2(36,3)=y(12)*T163*T207;
  v2(37,1)=3;
  v2(37,2)=124;
  v2(37,3)=  v2(36,3);
  v2(38,1)=3;
  v2(38,2)=179;
  v2(38,3)=T410;
  v2(39,1)=3;
  v2(39,2)=143;
  v2(39,3)=  v2(38,3);
  v2(40,1)=3;
  v2(40,2)=181;
  v2(40,3)=y(12)*T102*T310;
  v2(41,1)=3;
  v2(41,2)=45;
  v2(41,3)=T109*T218;
  v2(42,1)=3;
  v2(42,2)=117;
  v2(42,3)=  v2(41,3);
  v2(43,1)=3;
  v2(43,2)=39;
  v2(43,3)=T109*(-((-(params(3)*y(8)))/(y(8)*y(7)*y(8)*y(7))));
  v2(44,1)=3;
  v2(44,2)=3;
  v2(44,3)=  v2(43,3);
  v2(45,1)=3;
  v2(45,2)=46;
  v2(45,3)=T109*(-(T268/T216));
  v2(46,1)=3;
  v2(46,2)=136;
  v2(46,3)=  v2(45,3);
  v2(47,1)=3;
  v2(47,2)=64;
  v2(47,3)=T109*(params(3)*params(5)+params(3)*params(5));
  v2(48,1)=3;
  v2(48,2)=118;
  v2(48,3)=  v2(47,3);
  v2(49,1)=3;
  v2(49,2)=215;
  v2(49,3)=T189;
  v2(50,1)=3;
  v2(50,2)=107;
  v2(50,3)=  v2(49,3);
  v2(51,1)=3;
  v2(51,2)=216;
  v2(51,3)=T35*T207-(params(5)+params(5));
  v2(52,1)=3;
  v2(52,2)=126;
  v2(52,3)=  v2(51,3);
  v2(53,1)=3;
  v2(53,2)=217;
  v2(53,3)=T228;
  v2(54,1)=3;
  v2(54,2)=145;
  v2(54,3)=  v2(53,3);
  v2(55,1)=3;
  v2(55,2)=219;
  v2(55,3)=T102*T163;
  v2(56,1)=3;
  v2(56,2)=183;
  v2(56,3)=  v2(55,3);
  v2(57,1)=3;
  v2(57,2)=235;
  v2(57,3)=y(8)*2*params(5)/2;
  v2(58,1)=3;
  v2(58,2)=127;
  v2(58,3)=  v2(57,3);
  v2(59,1)=3;
  v2(59,2)=236;
  v2(59,3)=T98;
  v2(60,1)=3;
  v2(60,2)=146;
  v2(60,3)=  v2(59,3);
  v2(61,1)=4;
  v2(61,2)=120;
  v2(61,3)=T334;
  v2(62,1)=4;
  v2(62,2)=102;
  v2(62,3)=  v2(61,3);
  v2(63,1)=4;
  v2(63,2)=121;
  v2(63,3)=y(13)*2*params(5)/2+y(12)*params(4)*params(2)*y(6)/y(10)*T207+T109*y(3)*(-((T216*((y(8)*y(8)*y(7)+y(8)*y(8)*y(7))*(-(params(3)*y(1)))-((y(8)*y(8)*y(7)+y(8)*y(8)*y(7))*(-(params(3)*y(1)))+(-(y(7)*params(3)*y(1)))*(y(8)*y(8)+y(8)*y(8))))-(y(8)*y(7)*y(8)*y(7)*(-(params(3)*y(1)))-(-(y(7)*params(3)*y(1)))*(y(8)*y(8)*y(7)+y(8)*y(8)*y(7)))*T352)/(T216*T216)));
  v2(64,1)=4;
  v2(64,2)=301;
  v2(64,3)=y(11)*(-((-((-(params(3)*y(17)))*(y(17)*y(17)*y(16)+y(17)*y(17)*y(16))))/T433));
  v2(65,1)=4;
  v2(65,2)=7;
  v2(65,3)=T109*y(3)*(-((y(8)*y(7)*y(8)*y(7)*(-params(3))-(y(8)*y(8)*y(7)+y(8)*y(8)*y(7))*(-(params(3)*y(7))))/T216));
  v2(66,1)=4;
  v2(66,2)=115;
  v2(66,3)=  v2(65,3);
  v2(67,1)=4;
  v2(67,2)=140;
  v2(67,3)=T109*y(3)*(-((T216*(-((-(params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))+(-(y(7)*params(3)*y(1)))*(y(8)*y(7)+y(8)*y(7)+y(8)*y(7)+y(8)*y(7))))-(-((-(y(7)*params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))))*T352)/(T216*T216)));
  v2(68,1)=4;
  v2(68,2)=122;
  v2(68,3)=  v2(67,3);
  v2(69,1)=4;
  v2(69,2)=134;
  v2(69,3)=T109*y(3)*(-((-((-(params(3)*y(7)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))))/T216));
  v2(70,1)=4;
  v2(70,2)=8;
  v2(70,3)=  v2(69,3);
  v2(71,1)=4;
  v2(71,2)=141;
  v2(71,3)=y(15)*(-((y(8)+y(8))/(y(8)*y(8)*y(8)*y(8))))+T109*y(3)*(-((T216*(-((-(y(7)*params(3)*y(1)))*(y(7)*y(7)+y(7)*y(7))))-(-((-(y(7)*params(3)*y(1)))*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))))*(y(8)*y(7)*y(8)*y(7)*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))+y(8)*y(7)*y(8)*y(7)*(y(7)*y(8)*y(7)+y(7)*y(8)*y(7))))/(T216*T216)));
  v2(72,1)=4;
  v2(72,2)=320;
  v2(72,3)=y(11)*(-((y(17)*y(16)*y(17)*y(16)*(-params(3))-(-(params(3)*y(16)))*(y(17)*y(17)*y(16)+y(17)*y(17)*y(16)))/T433));
  v2(73,1)=4;
  v2(73,2)=302;
  v2(73,3)=  v2(72,3);
  v2(74,1)=4;
  v2(74,2)=321;
  v2(74,3)=y(11)*(-((-((-(params(3)*y(16)))*(y(16)*y(17)*y(16)+y(16)*y(17)*y(16))))/T433));
  v2(75,1)=4;
  v2(75,2)=177;
  v2(75,3)=T341;
  v2(76,1)=4;
  v2(76,2)=105;
  v2(76,3)=  v2(75,3);
  v2(77,1)=4;
  v2(77,2)=178;
  v2(77,3)=T410;
  v2(78,1)=4;
  v2(78,2)=124;
  v2(78,3)=  v2(77,3);
  v2(79,1)=4;
  v2(79,2)=181;
  v2(79,3)=T493;
  v2(80,1)=4;
  v2(80,2)=45;
  v2(80,3)=T109*T235;
  v2(81,1)=4;
  v2(81,2)=117;
  v2(81,3)=  v2(80,3);
  v2(82,1)=4;
  v2(82,2)=39;
  v2(82,3)=T109*(-((-(params(3)*y(7)))/(y(8)*y(7)*y(8)*y(7))));
  v2(83,1)=4;
  v2(83,2)=3;
  v2(83,3)=  v2(82,3);
  v2(84,1)=4;
  v2(84,2)=46;
  v2(84,3)=T109*T282;
  v2(85,1)=4;
  v2(85,2)=136;
  v2(85,3)=  v2(84,3);
  v2(86,1)=4;
  v2(86,2)=206;
  v2(86,3)=T246;
  v2(87,1)=4;
  v2(87,2)=296;
  v2(87,3)=  v2(86,3);
  v2(88,1)=4;
  v2(88,2)=207;
  v2(88,3)=T294;
  v2(89,1)=4;
  v2(89,2)=315;
  v2(89,3)=  v2(88,3);
  v2(90,1)=4;
  v2(90,2)=215;
  v2(90,3)=T193;
  v2(91,1)=4;
  v2(91,2)=107;
  v2(91,3)=  v2(90,3);
  v2(92,1)=4;
  v2(92,2)=216;
  v2(92,3)=T228;
  v2(93,1)=4;
  v2(93,2)=126;
  v2(93,3)=  v2(92,3);
  v2(94,1)=4;
  v2(94,2)=219;
  v2(94,3)=T289;
  v2(95,1)=4;
  v2(95,2)=183;
  v2(95,3)=  v2(94,3);
  v2(96,1)=4;
  v2(96,2)=235;
  v2(96,3)=T98;
  v2(97,1)=4;
  v2(97,2)=127;
  v2(97,3)=  v2(96,3);
  v2(98,1)=4;
  v2(98,2)=274;
  v2(98,3)=T277;
  v2(99,1)=4;
  v2(99,2)=148;
  v2(99,3)=  v2(98,3);
  v2(100,1)=6;
  v2(100,2)=120;
  v2(100,3)=T336;
  v2(101,1)=6;
  v2(101,2)=102;
  v2(101,3)=  v2(100,3);
  v2(102,1)=6;
  v2(102,2)=121;
  v2(102,3)=y(12)*T163*T207;
  v2(103,1)=6;
  v2(103,2)=139;
  v2(103,3)=T341;
  v2(104,1)=6;
  v2(104,2)=103;
  v2(104,3)=  v2(103,3);
  v2(105,1)=6;
  v2(105,2)=140;
  v2(105,3)=T410;
  v2(106,1)=6;
  v2(106,2)=122;
  v2(106,3)=  v2(105,3);
  v2(107,1)=6;
  v2(107,2)=177;
  v2(107,3)=T347;
  v2(108,1)=6;
  v2(108,2)=105;
  v2(108,3)=  v2(107,3);
  v2(109,1)=6;
  v2(109,2)=178;
  v2(109,3)=y(12)*T102*T310;
  v2(110,1)=6;
  v2(110,2)=124;
  v2(110,3)=  v2(109,3);
  v2(111,1)=6;
  v2(111,2)=179;
  v2(111,3)=T493;
  v2(112,1)=6;
  v2(112,2)=143;
  v2(112,3)=  v2(111,3);
  v2(113,1)=6;
  v2(113,2)=181;
  v2(113,3)=y(14)*(y(10)+y(10))/(y(10)*y(10)*y(10)*y(10))+y(12)*T42*params(4)*(y(10)*y(10)*y(10)*y(10)*(-(2*(-(y(8)*params(2)*y(6)))))-(-((-(y(8)*params(2)*y(6)))*(y(10)+y(10))))*(y(10)*y(10)*(y(10)+y(10))+y(10)*y(10)*(y(10)+y(10))))/(y(10)*y(10)*y(10)*y(10)*y(10)*y(10)*y(10)*y(10))+params(10)*y(18)*(-(params(6)*(y(10)+y(10))/(y(10)*y(10)*y(10)*y(10))));
  v2(114,1)=6;
  v2(114,2)=215;
  v2(114,3)=T199;
  v2(115,1)=6;
  v2(115,2)=107;
  v2(115,3)=  v2(114,3);
  v2(116,1)=6;
  v2(116,2)=216;
  v2(116,3)=T102*T163;
  v2(117,1)=6;
  v2(117,2)=126;
  v2(117,3)=  v2(116,3);
  v2(118,1)=6;
  v2(118,2)=217;
  v2(118,3)=T289;
  v2(119,1)=6;
  v2(119,2)=145;
  v2(119,3)=  v2(118,3);
  v2(120,1)=6;
  v2(120,2)=219;
  v2(120,3)=T42*T310;
  v2(121,1)=6;
  v2(121,2)=183;
  v2(121,3)=  v2(120,3);
  v2(122,1)=6;
  v2(122,2)=234;
  v2(122,3)=(-1);
  v2(123,1)=6;
  v2(123,2)=108;
  v2(123,3)=  v2(122,3);
  v2(124,1)=6;
  v2(124,2)=257;
  v2(124,3)=T303;
  v2(125,1)=6;
  v2(125,2)=185;
  v2(125,3)=  v2(124,3);
  v2(126,1)=6;
  v2(126,2)=333;
  v2(126,3)=params(10)*(-(params(6)*T303));
  v2(127,1)=6;
  v2(127,2)=189;
  v2(127,3)=  v2(126,3);
  v2(128,1)=7;
  v2(128,2)=81;
  v2(128,3)=T184;
  v2(129,1)=7;
  v2(129,2)=301;
  v2(129,3)=(-((-((-(params(3)*y(8)*y(17)))*(y(17)*y(17)*y(16)+y(17)*y(17)*y(16))))/T433));
  v2(130,1)=7;
  v2(130,2)=149;
  v2(130,3)=T246;
  v2(131,1)=7;
  v2(131,2)=293;
  v2(131,3)=  v2(130,3);
  v2(132,1)=7;
  v2(132,2)=320;
  v2(132,3)=(-((y(17)*y(16)*y(17)*y(16)*(-(params(3)*y(8)))-(-(params(3)*y(8)*y(16)))*(y(17)*y(17)*y(16)+y(17)*y(17)*y(16)))/T433));
  v2(133,1)=7;
  v2(133,2)=302;
  v2(133,3)=  v2(132,3);
  v2(134,1)=7;
  v2(134,2)=312;
  v2(134,3)=T294;
  v2(135,1)=7;
  v2(135,2)=150;
  v2(135,3)=  v2(134,3);
  v2(136,1)=7;
  v2(136,2)=321;
  v2(136,3)=(-((-((-(params(3)*y(8)*y(16)))*(y(16)*y(17)*y(16)+y(16)*y(17)*y(16))))/T433));
  v2(137,1)=8;
  v2(137,2)=120;
  v2(137,3)=T189;
  v2(138,1)=8;
  v2(138,2)=102;
  v2(138,3)=  v2(137,3);
  v2(139,1)=8;
  v2(139,2)=121;
  v2(139,3)=T35*T207-(params(5)+params(5));
  v2(140,1)=8;
  v2(140,2)=301;
  v2(140,3)=params(3)*params(5)+params(3)*params(5);
  v2(141,1)=8;
  v2(141,2)=139;
  v2(141,3)=T193;
  v2(142,1)=8;
  v2(142,2)=103;
  v2(142,3)=  v2(141,3);
  v2(143,1)=8;
  v2(143,2)=140;
  v2(143,3)=T228;
  v2(144,1)=8;
  v2(144,2)=122;
  v2(144,3)=  v2(143,3);
  v2(145,1)=8;
  v2(145,2)=177;
  v2(145,3)=T199;
  v2(146,1)=8;
  v2(146,2)=105;
  v2(146,3)=  v2(145,3);
  v2(147,1)=8;
  v2(147,2)=178;
  v2(147,3)=T102*T163;
  v2(148,1)=8;
  v2(148,2)=124;
  v2(148,3)=  v2(147,3);
  v2(149,1)=8;
  v2(149,2)=179;
  v2(149,3)=T289;
  v2(150,1)=8;
  v2(150,2)=143;
  v2(150,3)=  v2(149,3);
  v2(151,1)=8;
  v2(151,2)=181;
  v2(151,3)=T42*T310;
  v2(152,1)=9;
  v2(152,2)=121;
  v2(152,3)=y(8)*2*params(5)/2;
  v2(153,1)=9;
  v2(153,2)=140;
  v2(153,3)=T98;
  v2(154,1)=9;
  v2(154,2)=122;
  v2(154,3)=  v2(153,3);
  v2(155,1)=9;
  v2(155,2)=177;
  v2(155,3)=(-1);
  v2(156,1)=9;
  v2(156,2)=105;
  v2(156,3)=  v2(155,3);
  v2(157,1)=10;
  v2(157,2)=21;
  v2(157,3)=(-(params(6)*(-1)/(y(2)*y(2))));
  v2(158,1)=10;
  v2(158,2)=181;
  v2(158,3)=T303;
  v2(159,1)=11;
  v2(159,2)=101;
  v2(159,3)=2*params(2)/2;
  v2(160,1)=11;
  v2(160,2)=141;
  v2(160,3)=T277;
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),11,361);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],11,6859);
end
end
