function [residual, g1, g2] = modelans4_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 11, 1);

%
% Model equations
%

T12 = (-1)/((1+y(1))*(1+y(1)));
T33 = 1+params(5)*(y(3)-1)^2/2;
T39 = T33*params(4)*params(2)*y(4)/y(6);
T47 = y(4)*params(5)/2*2*(y(3)-1);
T61 = (1+params(8)-params(4)/(params(4)-1))*(1-params(4))+params(4)*(y(4)*params(2)*y(2)/y(6)-1);
T63 = params(5)*2*(y(3)-1)/2;
T71 = params(10)^(-1);
T79 = (-((-(y(4)*y(4)*params(3)))/(y(3)*y(4)*y(3)*y(4))));
T96 = 1+(y(3)-1)^2*params(5)/2;
T100 = T33*params(4)*params(2)*y(2)/y(6);
T119 = 1/y(6);
T127 = T33*params(4)*(-(y(4)*params(2)*y(2)))/(y(6)*y(6));
T175 = y(8)*params(4)*params(2)*y(4)/y(6)*T63;
residual(1) = y(7)*T12;
residual(2) = y(11)*params(2)*2*y(2)/2+y(9)*(-y(6))+y(8)*T39;
residual(3) = y(9)*T47+y(8)*(T61*T63-(params(5)*(y(3)-1)+params(5)*y(3)))+T71*y(7)*T79+T71*y(8)*((y(3)-1)*params(5)*params(3)+y(3)*params(5)*params(3));
residual(4) = y(11)*(-(1/y(4)))+y(9)*T96+y(8)*T100+y(7)*(-(params(3)/(y(3)*y(4))))+T71*y(7)*(-((-(y(3)*y(4)*params(3)))/(y(3)*y(4)*y(3)*y(4))));
residual(5) = 1+y(11);
residual(6) = y(10)*T119+y(9)*(-y(2))+y(8)*T127+params(10)*y(10)*(-(T119*params(6)));
residual(7) = 1/(1+y(1))-y(4)*params(3)/(y(3)*y(4));
residual(8) = T33*T61-y(3)*params(5)*(y(3)-1)+y(3)*(y(3)-1)*params(5)*params(3);
residual(9) = y(4)*T96-y(2)*y(6);
residual(10) = log(y(6))-(params(6)*log(y(6))+x(1));
residual(11) = y(5)-(log(y(4))-params(2)*y(2)^2/2);
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(11, 11);

  %
  % Jacobian matrix
  %

  g1(1,1)=y(7)*(1+y(1)+1+y(1))/((1+y(1))*(1+y(1))*(1+y(1))*(1+y(1)));
  g1(1,7)=T12;
  g1(2,2)=y(11)*2*params(2)/2;
  g1(2,3)=T175;
  g1(2,4)=y(8)*T33*params(4)*params(2)/y(6);
  g1(2,6)=(-y(9))+y(8)*T33*params(4)*(-(params(2)*y(4)))/(y(6)*y(6));
  g1(2,8)=T39;
  g1(2,9)=(-y(6));
  g1(2,11)=params(2)*2*y(2)/2;
  g1(3,2)=T175;
  g1(3,3)=y(9)*y(4)*2*params(5)/2+y(8)*(T61*2*params(5)/2-(params(5)+params(5)))+T71*y(7)*(-((-((-(y(4)*y(4)*params(3)))*(y(4)*y(3)*y(4)+y(4)*y(3)*y(4))))/(y(3)*y(4)*y(3)*y(4)*y(3)*y(4)*y(3)*y(4))))+T71*y(8)*(params(5)*params(3)+params(5)*params(3));
  g1(3,4)=y(9)*params(5)/2*2*(y(3)-1)+y(8)*T63*params(4)*params(2)*y(2)/y(6)+T71*y(7)*(-((y(3)*y(4)*y(3)*y(4)*(-(y(4)*params(3)+y(4)*params(3)))-(-(y(4)*y(4)*params(3)))*(y(3)*y(3)*y(4)+y(3)*y(3)*y(4)))/(y(3)*y(4)*y(3)*y(4)*y(3)*y(4)*y(3)*y(4))));
  g1(3,6)=y(8)*T63*params(4)*(-(y(4)*params(2)*y(2)))/(y(6)*y(6));
  g1(3,7)=T71*T79;
  g1(3,8)=T61*T63-(params(5)*(y(3)-1)+params(5)*y(3))+T71*((y(3)-1)*params(5)*params(3)+y(3)*params(5)*params(3));
  g1(3,9)=T47;
  g1(4,2)=y(8)*T33*params(4)*params(2)/y(6);
  g1(4,3)=y(9)*params(5)/2*2*(y(3)-1)+y(8)*T63*params(4)*params(2)*y(2)/y(6)+y(7)*(-((-(y(4)*params(3)))/(y(3)*y(4)*y(3)*y(4))))+T71*y(7)*(-((y(3)*y(4)*y(3)*y(4)*(-(y(4)*params(3)))-(-(y(3)*y(4)*params(3)))*(y(4)*y(3)*y(4)+y(4)*y(3)*y(4)))/(y(3)*y(4)*y(3)*y(4)*y(3)*y(4)*y(3)*y(4))));
  g1(4,4)=y(11)*(-((-1)/(y(4)*y(4))))+y(7)*(-((-(y(3)*params(3)))/(y(3)*y(4)*y(3)*y(4))))+T71*y(7)*(-((y(3)*y(4)*y(3)*y(4)*(-(y(3)*params(3)))-(-(y(3)*y(4)*params(3)))*(y(3)*y(3)*y(4)+y(3)*y(3)*y(4)))/(y(3)*y(4)*y(3)*y(4)*y(3)*y(4)*y(3)*y(4))));
  g1(4,6)=y(8)*T33*params(4)*(-(params(2)*y(2)))/(y(6)*y(6));
  g1(4,7)=(-(params(3)/(y(3)*y(4))))+T71*(-((-(y(3)*y(4)*params(3)))/(y(3)*y(4)*y(3)*y(4))));
  g1(4,8)=T100;
  g1(4,9)=T96;
  g1(4,11)=(-(1/y(4)));
  g1(5,11)=1;
  g1(6,2)=(-y(9))+y(8)*T33*params(4)*(-(params(2)*y(4)))/(y(6)*y(6));
  g1(6,3)=y(8)*T63*params(4)*(-(y(4)*params(2)*y(2)))/(y(6)*y(6));
  g1(6,4)=y(8)*T33*params(4)*(-(params(2)*y(2)))/(y(6)*y(6));
  g1(6,6)=y(10)*(-1)/(y(6)*y(6))+y(8)*T33*params(4)*(-((-(y(4)*params(2)*y(2)))*(y(6)+y(6))))/(y(6)*y(6)*y(6)*y(6))+params(10)*y(10)*(-(params(6)*(-1)/(y(6)*y(6))));
  g1(6,8)=T127;
  g1(6,9)=(-y(2));
  g1(6,10)=T119+params(10)*(-(T119*params(6)));
  g1(7,1)=T12;
  g1(7,3)=T79;
  g1(7,4)=(-((params(3)*y(3)*y(4)-y(3)*y(4)*params(3))/(y(3)*y(4)*y(3)*y(4))));
  g1(8,2)=T39;
  g1(8,3)=T61*T63-(params(5)*(y(3)-1)+params(5)*y(3))+(y(3)-1)*params(5)*params(3)+y(3)*params(5)*params(3);
  g1(8,4)=T100;
  g1(8,6)=T127;
  g1(9,2)=(-y(6));
  g1(9,3)=T47;
  g1(9,4)=T96;
  g1(9,6)=(-y(2));
  g1(10,6)=T119-T119*params(6);
  g1(11,2)=params(2)*2*y(2)/2;
  g1(11,4)=(-(1/y(4)));
  g1(11,5)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],11,121);
end
end
